Learn R Programming

LPCM (version 0.41-6)

LPCM-package: Local principal curve methods

Description

Fitting multivariate data patterns with local principal curves; including simple tools for data compression (projection), bandwidth selection, and measuring goodness-of-fit.

This packages implements the techniques introduced in Einbeck, Tutz & Evers (2005), and successive related papers.

The main functions to be called by the user are

  • lpc, for the estimation of the local centers of mass which make up the principal curve;
  • lpc.spline, which is a smooth and fully parametrized cubic spline respresentation of the latter;
  • lpc.project, which enables to compress data by projecting them orthogonally onto the curve;
  • lpc.coverageandlpc.Rcfor assessing goodness-of-fit;
  • lpc.self.coveragefor bandwidth selection;
  • the genericplotandprintfunctions for objects of classlpcandlpc.spline.
This package also contains some (rather experimental) code for density mode detection and mean shift clustering, see ms.

A second R package which will implement the extension of local principal curves to local principal surfaces and manifolds, as proposed in Einbeck, Evers & Powell (2010), is in preparation.

Arguments

Details

ll{ Package: LPCM Type: Package License: GPL 2.0 or newer. LazyLoad: yes }

References

Einbeck, J., Tutz, G., & Evers, L. (2005), Local principal curves, Statistics and Computing 15, 301-313.

Einbeck, J., Evers, L., & Powell, B. (2010): Data compression and regression through local principal curves and surfaces, International Journal of Neural Systems, 20, 177-192.

See Also

pcurve, princurve