Learn R Programming

LPCM (version 0.41-6)

calspeedflow: Speed-flow data from Calfornia.

Description

A `fundamental diagram' with observations of speed and flow recorded from 9th of July 2007, 9am, to 10th of July 2007, 10pm, on Line 5 of the Californian Freeway SR57-N, VDS number 1202263. The data were originally measured in intervals of thirty seconds, and then aggregated over intervals of 5 minutes length.

Usage

data(calspeedflow)

Arguments

source

Retrieved from PeMS.

References

Einbeck, J., and Dwyer, J. (2010). Using principal curves to identify different traffic patterns on freeways. Transportmetrica, to appear.

Examples

Run this code
data(calspeedflow)
plot(calspeedflow[,3:4])

Run the code above in your browser using DataLab