coverage.raw(X, vec, tau, weights=1, plot.type="p", print=FALSE,
label=NULL,...)coverage(X, vec, taumin=0.02, taumax, gridsize=25, weights=1,
plot.type="o", print=TRUE,...)
lpc.coverage(object, taumin=0.02, taumax, gridsize=25, quick=TRUE,
plot.type="o", print=TRUE, ...)
lpc.self.coverage(X, taumin=0.02, taumax=0.5, gridsize=25, x0, mult=1,
way = "two", scaled=TRUE, weights=1, pen=2, depth=1,
control=lpc.control(boundary=0, cross=FALSE), quick=TRUE,
plot.type="o", print=TRUE, ... )
select.self.coverage(self, sens=0.02, from, plot.type="o", auto=FALSE)
lpc or lpc.spline.lpc.coverage does not have a
weights argument, aself, or a matrix with two colums
providing a self-coverage curve.sens, are selected.TRUE, the sensitivity is decreased
until a bandwidth is selected.gridsize is large.lpc and lpc.control.plot.type=0). For function lpc.self.coverage, the item $select recommends suitable
bandwidths for the use in lpc. These correspond to
points of strong negative curvature (implemented via second
differences) of the self-coverage curve.
Functions coverage.raw and coverage can be used for any
object fitted by an unsupervised learning technique (for instance, HS principal curves, or even clustering
algorithms), while the functions prefixing with lpc. can only be
used for local principal curves. The function lpc.coverage is a wrapper around
coverage which takes directly a fitted lpc object, rather
than a data matrix.
Function select.self.coverage is called by
lpc.self.coverage. It extracts suitable bandwidths from the
self-coverage curve, and produces a plot. The function can be called
directly by the user if the sensitivity sens or the minimum
coverage from are to be modified.
lpcdata(gvessel)
gvessel.lpc <- lpc(gvessel[,c(2,4,5)], h=0.11, x0=c(35, 1870, 6.3))
lpc.coverage(gvessel.lpc, gridsize=10, print=FALSE)
lpc.self.coverage(gvessel[,c(2,4,5)], x0=c(35, 1870, 6.3), print=FALSE)
data(calspeedflow)
fitms <- ms(calspeedflow[,3:4], h=0.1)
coverage(fitms$data, fitms$cluster.center)Run the code above in your browser using DataLab